# Oops, I did it again

An unexpected error occurred. Do you want to send a bug report? This is automatic, and prevents similar problems in the future.

[Send the error message](opensesame://event.bug_report_send){: .important-button}

Privacy:

- The error message (see below) may contain identifying information, such as your user name. If so, this information will not be used for any other purpose than fixing bugs.

Information:

- Operating System: %(platform)s
- OpenSesame: %(version)s
- Python: %(python_version)s

Don't show me this message!

- If you don't want to see bug-report messages in the future, you can disable the bug_report extension under Menu → Tools → Plug-in and extension manager. This does not automagically solve the problem--it only suppresses the report!

Error message:

%(traceback)s
